@@ -105,6 +105,14 @@ Magick::Color Color(const char * str){
   return val;
 }
 
+Magick::OrientationType Orientation(const char * str){
+  ssize_t val = MagickCore::ParseCommandOption(
+    MagickCore::MagickOrientationOptions, Magick::MagickFalse, str);
+  if(val < 0)
+    throw std::runtime_error(std::string("Invalid OrientationType value: ") + str);
+  return (Magick::OrientationType) val;
+}
+
 #if MagickLibVersion >= 0x700
 Magick::Point Point(const char * str){
   Magick::Point point(str);
@@ -131,7 +139,16 @@ XPtrImage magick_image_blur( XPtrImage input, const double radius = 1, const dou
 // [[Rcpp::export]]
 XPtrImage magick_image_charcoal( XPtrImage input, const double radius = 1, const double sigma = 0.5){
   XPtrImage output = copy(input);
+#if MagickLibVersion >= 0x700
+  for(size_t i = 0; i < output->size(); i++){
+    MagickCore::Image *im = output->at(i).image();
+    Magick::ChannelType old = MagickCore::SetImageChannelMask(im, Magick::ChannelType(Magick::CompositeChannels ^ Magick::AlphaChannel));
+    output->at(i).charcoal(radius, sigma);
+    MagickCore::SetImageChannelMask(im, old);
+  }
+#else
   for_each ( output->begin(), output->end(), Magick::charcoalImage(radius, sigma));
+#endif
   return output;
 }
 
@@ -238,6 +255,24 @@ XPtrImage magick_image_repage( XPtrImage input){
   return output;
 }
 
+// [[Rcpp::export]]
+XPtrImage magick_image_orient( XPtrImage input, Rcpp::CharacterVector orientation){
+  XPtrImage output = copy(input);
+  for(size_t i = 0; i < output->size(); i++){
+    if(orientation.length()){
+      output->at(i).orientation(Orientation(orientation.at(0)));
+    } else {
+      //https://github.com/ImageMagick/ImageMagick/commit/b559cab
+#if MagickLibVersion >= 0x686
+      output->at(i).autoOrient();
+#else
+      Rcpp::warning("ImageMagick too old to support autoOrient (requires >= 6.8.6)");
+#endif
+    }
+  }
+  return output;
+}
+
 // [[Rcpp::export]]
 XPtrImage magick_image_despeckle( XPtrImage input, int times){
   XPtrImage output = copy(input);
